@@ -64,11 +64,15 @@ from bzrlib.plugins.fastimport import (
     )
 
 from fastimport import commands
+from bzrlib.plugins.fastimport.helpers import (
+    binary_stream,
+    single_plural,
+    )
 
 
 def _get_output_stream(destination):
     if destination is None or destination == '-':
-        return sys.stdout
+        return binary_stream(sys.stdout)
     elif destination.endswith('gz'):
         import gzip
         return gzip.open(destination, 'wb')
@@ -145,7 +149,7 @@ class BzrFastExporter(object):
     def __init__(self, source, outf, ref=None, checkpoint=-1,
         import_marks_file=None, export_marks_file=None, revision=None,
         verbose=False, plain_format=False, rewrite_tags=False,
-        baseline=False):
+        no_tags=False, baseline=False):
         """Export branch data in fast import format.
 
         :param plain_format: if True, 'classic' fast-import format is
@@ -156,6 +160,7 @@ class BzrFastExporter(object):
             will be rewritten to be git-compatible.
             Otherwise tags which aren't valid for git will be skipped if
             plain_format is set.
+        :param no_tags: if True tags won't be exported at all
         """
         self.branch = source
         self.outf = outf
@@ -167,6 +172,7 @@ class BzrFastExporter(object):
         self.excluded_revisions = set()
         self.plain_format = plain_format
         self.rewrite_tags = rewrite_tags
+        self.no_tags = no_tags
         self.baseline = baseline
         self._multi_author_api_available = hasattr(bzrlib.revision.Revision,
             'get_apparent_authors')
@@ -232,7 +238,7 @@ class BzrFastExporter(object):
                 self.emit_baseline(interesting.pop(0), self.ref)
             for revid in interesting:
                 self.emit_commit(revid, self.ref)
-            if self.branch.supports_tags():
+            if self.branch.supports_tags() and not self.no_tags:
                 self.emit_tags()
         finally:
             self.branch.repository.unlock()
@@ -273,7 +279,9 @@ class BzrFastExporter(object):
     def dump_stats(self):
         time_required = progress.str_tdelta(time.time() - self._start_time)
         rc = len(self.revid_to_mark)
-        self.note("Exported %d %s in %s", rc, "revision(s)", time_required)
+        self.note("Exported %d %s in %s",
+            rc, single_plural(rc, "revision", "revisions"),
+            time_required)
 
     def print_cmd(self, cmd):
         self.outf.write("%r\n" % cmd)
@@ -428,7 +436,7 @@ class BzrFastExporter(object):
                     pass
 
         # Build and return the result
-        return commands.CommitCommand(git_ref, mark, author_info,
+        return commands.CommitCommand(git_ref, str(mark), author_info,
             committer_info, revobj.message.encode("utf-8"), from_, merges, iter(file_cmds),
             more_authors=more_author_info, properties=properties)
 
